<?php
// Pengaturan path direktori utama
$base_dir = "/home/mldyznjtda/";

// Fungsi untuk membaca data dari file CSV
function read_domains_from_csv($file_path) {
    $domains = [];
    if (($handle = fopen($file_path, "r")) !== false) {
        $header = fgetcsv($handle); // Membaca header
        while (($data = fgetcsv($handle)) !== false) {
            $domains[$data[0]] = [
                'keyword' => $data[1],
                'title' => $data[2],
                'description' => $data[3],
                'article' => $data[4],
                'image' => $data[5],
                'logo' => $data[6],
                'amp' => $data[7],
            ];
        }
        fclose($handle);
    }
    return $domains;
}

// Fungsi untuk menghasilkan SKU unik
function generate_sku($keyword) {
    $keyword_part = strtoupper(substr(preg_replace('/[^a-zA-Z0-9]/', '', $keyword), 0, 4)); // Ambil 4 huruf pertama dari keyword
    $random_number = rand(1000, 9999); // Angka acak 4 digit
    return "SKU-{$keyword_part}-{$random_number}"; // Format: SKU-XXXX-1234
}

// Fungsi untuk memilih template secara acak
function get_random_template() {
    $template_folder = 'templates/';
    $templates = glob($template_folder . '*.html');
    if (empty($templates)) {
        return "<html><body><h1>Error: Tidak ada template ditemukan di folder templates/</h1></body></html>";
    }
    
    // Pilih indeks acak dari array templates
    $random_index = rand(0, count($templates) - 1);
    return file_get_contents($templates[$random_index]);
}

// Fungsi untuk membuat file landing page
function create_landing_page($domain, $content, $base_dir) {
    $target_dir = $base_dir . $domain . '/';
    $file_path = $target_dir . 'index.html'; // File landing page

    // Generate SKU
    $sku = generate_sku($content['keyword']);

    // Membaca template acak
    $template = get_random_template();

    // Mengganti placeholder dengan konten yang sesuai
    $html_content = str_replace(
        ['{{title}}', '{{description}}', '{{article}}', '{{canonical}}', '{{keyword}}', '{{image}}', '{{logo}}', '{{amp}}', '{{sku}}'],
        [$content['title'], $content['description'], $content['article'], $domain, $content['keyword'], $content['image'], $content['logo'], $content['amp'], $sku],
        $template
    );

    // Simpan konten HTML ke file
    if (!is_dir($target_dir)) {
        mkdir($target_dir, 0755, true); // Membuat direktori jika belum ada
    }

    // Cek apakah index.html sudah ada, lalu beri notifikasi sesuai kondisi
    if (file_exists($file_path)) {
        file_put_contents($file_path, $html_content);
        echo "Landing page untuk $domain berhasil diganti (replace).\n";
    } else {
        file_put_contents($file_path, $html_content);
        echo "Landing page untuk $domain berhasil dibuat.\n";
    }

    // Buat file robots.txt
    create_robots_txt($domain, $target_dir);

    // Buat file sitemap.xml
    create_sitemap_xml($domain, $target_dir);
}

// Fungsi untuk membuat file robots.txt
function create_robots_txt($domain, $target_dir) {
    $robots_content = "User-agent: *\nAllow: /\nSitemap: https://$domain/sitemap.xml\n";
    $robots_path = $target_dir . 'robots.txt';
    file_put_contents($robots_path, $robots_content);
    echo "robots.txt untuk $domain berhasil dibuat.\n";
}

// Fungsi untuk membuat file sitemap.xml
function create_sitemap_xml($domain, $target_dir) {
    $sitemap_content = <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">
    <url>
        <loc>https://$domain/</loc>
        <changefreq>daily</changefreq>
        <priority>1.0</priority>
    </url>
</urlset>
XML;
    $sitemap_path = $target_dir . 'sitemap.xml';
    file_put_contents($sitemap_path, $sitemap_content);
    echo "sitemap.xml untuk $domain berhasil dibuat.\n";
}

// Membaca daftar domain dari file CSV
$domains = read_domains_from_csv('domain.csv');

// Loop melalui setiap domain dan buat landing page
foreach ($domains as $domain => $content) {
    create_landing_page($domain, $content, $base_dir);
}
?>